## [0.0.2] - 2025-02-23
### Added
- Included minimal tests for NornFlowSettings, NornFlow and Workflow.
- Several minor bug-fixes [non-breaking]
- Models updated for bug fixes and improvements [non-breaking]
- Cosmetic documentation updates

## [0.0.1] - 2025-02-22
### Prototype version released
- Users can create basic Workflows through .yaml files. 
- Basic 'hosts' and 'groups' filtering through lists.
- Automatic Tasks discovery based on Settings - currently 'local' only.
- Automatic Workflows discovery based on Settings - currently 'local' only. 
- Includes a CLI that allows running tasks either in Ad-hoc (single task) or as a Workflow.